@@ -1,5 +1,5 @@
 document.getElementById("Contents").innerHTML='\
-    <ul><li><input type="checkbox" id="07"><label for="07">Macros and Programming</label><ul>\
+    <ul><li><input type="checkbox" id="07"><label for="07">Macros and Scripting</label><ul>\
     <li><input type="checkbox" id="0701"><label for="0701">מידע כללי ושימוש במנשק המשתמש</label><ul>\
     <li><a target="_top" href="he/text/sbasic/shared/main0601.html">LibreOffice Basic Help</a></li>\
     <li><a target="_top" href="he/text/sbasic/shared/01000000.html">Programming with LibreOffice Basic</a></li>\
@@ -124,6 +124,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="he/text/sbasic/shared/03090202.html">For...Next Statement</a></li>\
     <li><a target="_top" href="he/text/sbasic/shared/03120301.html">Format Function</a></li>\
     <li><a target="_top" href="he/text/sbasic/shared/03150000.html">FormatDateTime Function [VBA]</a></li>\
+    <li><a target="_top" href="he/text/sbasic/shared/03170010.html">FormatNumber Function [VBA]</a></li>\
     <li><a target="_top" href="he/text/sbasic/shared/03020102.html">FreeFile Function</a></li>\
     <li><a target="_top" href="he/text/sbasic/shared/03090405.html">FreeLibrary Function</a></li>\
     <li><a target="_top" href="he/text/sbasic/shared/03090406.html">Function Statement</a></li>\
@@ -297,7 +298,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="he/text/sbasic/guide/access2base.html">Access2Base</a></li>\
 		</ul></li>\
 	</ul></li></ul>\
-    <ul><li><input type="checkbox" id="08"><label for="08">גיליונות אלקטרוניים</label><ul>\
+    <ul><li><input type="checkbox" id="08"><label for="08">Spreadsheets (Calc)</label><ul>\
     <li><input type="checkbox" id="0801"><label for="0801">מידע כללי ושימוש במנשק המשתמש</label><ul>\
     <li><a target="_top" href="he/text/scalc/main0000.html">ברוכים הבאים לסיוע &#39;קאלק&#39; של LibreOffice</a></li>\
     <li><a target="_top" href="he/text/scalc/main0503.html">יכולות LibreOffice קאלק</a></li>\
@@ -477,7 +478,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="he/text/schart/04/01020000.html">Shortcuts for Charts</a></li>\
 		</ul></li>\
 	</ul></li></ul>\
-    <ul><li><input type="checkbox" id="01"><label for="01">התקנה</label><ul>\
+    <ul><li><input type="checkbox" id="01"><label for="01">LibreOffice Installation</label><ul>\
     <li><a target="_top" href="he/text/shared/guide/ms_doctypes.html">Changing the Association of Microsoft Office Document Types</a></li>\
     <li><a target="_top" href="he/text/shared/01/profile_safe_mode.html">Safe Mode</a></li>\
 	</ul></li></ul>\
@@ -503,7 +504,6 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="he/text/shared/optionen/01010200.html">General</a></li>\
     <li><a target="_top" href="he/text/shared/optionen/01010300.html">Paths</a></li>\
     <li><a target="_top" href="he/text/shared/optionen/01010400.html">Writing Aids</a></li>\
-    <li><a target="_top" href="he/text/shared/optionen/01010500.html">Color</a></li>\
     <li><a target="_top" href="he/text/shared/optionen/01010600.html">General</a></li>\
     <li><a target="_top" href="he/text/shared/optionen/01010700.html">Fonts</a></li>\
     <li><a target="_top" href="he/text/shared/optionen/01010800.html">View</a></li>\
@@ -661,7 +661,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="he/text/shared/guide/numbering_stop.html">Turning off Bullets and Numbering for Individual Paragraphs</a></li>\
 		</ul></li>\
 	</ul></li></ul>\
-    <ul><li><input type="checkbox" id="09"><label for="09">תפעול מסדי נתונים</label><ul>\
+    <ul><li><input type="checkbox" id="09"><label for="09">Database Functionality (Base)</label><ul>\
     <li><input type="checkbox" id="0901"><label for="0901">מידע כללי</label><ul>\
     <li><a target="_top" href="he/text/shared/explorer/database/main.html">LibreOffice Database</a></li>\
     <li><a target="_top" href="he/text/shared/guide/database_main.html">Database Overview</a></li>\
@@ -675,7 +675,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="he/text/shared/guide/data_enter_sql.html">Executing SQL Commands</a></li>\
 		</ul></li>\
 	</ul></li></ul>\
-    <ul><li><input type="checkbox" id="04"><label for="04">מצגות וציורים</label><ul>\
+    <ul><li><input type="checkbox" id="04"><label for="04">Presentations and Drawings (Impress/Draw)</label><ul>\
     <li><input type="checkbox" id="0401"><label for="0401">מידע כללי ושימוש במנשק המשתמש</label><ul>\
     <li><a target="_top" href="he/text/simpress/main0000.html">Welcome to the LibreOffice Impress Help</a></li>\
     <li><a target="_top" href="he/text/sdraw/main0000.html">ברוכים הבאים לסיוע &#39;קאלק&#39; של LibreOffice</a></li>\
@@ -820,7 +820,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="he/text/simpress/guide/rehearse_timings.html">Rehearse Timings of Slide Changes</a></li>\
          </ul></li>\
      </ul></li></ul>\
-    <ul><li><input type="checkbox" id="03"><label for="03">נוסחאות</label><ul>\
+    <ul><li><input type="checkbox" id="03"><label for="03">Formulas (Math)</label><ul>\
     <li><input type="checkbox" id="0301"><label for="0301">מידע כללי ושימוש במנשק המשתמש</label><ul>\
     <li><a target="_top" href="he/text/smath/main0000.html">Welcome to the LibreOffice Math Help</a></li>\
     <li><a target="_top" href="he/text/smath/main0503.html">יכולות LibreOffice קאלק</a></li>\
@@ -840,7 +840,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="he/text/smath/guide/parentheses.html">Inserting Brackets</a></li>\
 		</ul></li>\
 	</ul></li></ul>\
-    <ul><li><input type="checkbox" id="02"><label for="02">מסמכי טקסט</label><ul>\
+    <ul><li><input type="checkbox" id="02"><label for="02">Text Documents (Writer)</label><ul>\
     <li><input type="checkbox" id="0201"><label for="0201">מידע כללי ושימוש במנשק המשתמש</label><ul>\
     <li><a target="_top" href="he/text/swriter/main0000.html">ברוכים הבאים לסיוע &#39;קאלק&#39; של LibreOffice</a></li>\
     <li><a target="_top" href="he/text/swriter/main0503.html">יכולות LibreOffice קאלק</a></li>\
@@ -1049,7 +1049,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="he/text/shared/01/02100001.html">List of Regular Expressions</a></li>\
 		</ul></li>\
 	</ul></li></ul>\
-    <ul><li><input type="checkbox" id="06"><label for="06">מסמכי HTML</label><ul>\
+    <ul><li><input type="checkbox" id="06"><label for="06">HTML Documents (Writer Web)</label><ul>\
     <li><a target="_top" href="he/text/shared/07/09000000.html">Web Pages</a></li>\
     <li><a target="_top" href="he/text/shared/02/01170700.html">HTML Filters and Forms</a></li>\
     <li><a target="_top" href="he/text/swriter/guide/send2html.html">Saving Text Documents in HTML Format</a></li>\
